@@ -1,15 +1,13 @@
 module.exports = function (ctx) {
   return {
     parser: ctx.parser ? 'sugarss' : false,
-    syntax: 'postcss-scss',
+    syntax: ctx.syntax ? 'sugarss' : false,
     map: ctx.map ? 'inline' : false,
     from: './test/js/object/fixtures/index.css',
     to: './test/js/object/expect/index.css',
     plugins: {
       'postcss-import': {},
       'postcss-nested': {},
-      'postcss-sprites': {},
-      'postcss-cssnext': {},
       'cssnano': ctx.env === 'production' ? {} : false
     }
   }
